shithub: neatpost

Download patch

ref: 4e1e04ac903989a6973d5b9c4df1821f0e1d9366
parent: 88348db635583148977a1cd2122d0e9377c64efd
author: Ali Gholami Rudi <ali@rudi.ir>
date: Tue Sep 16 14:14:03 EDT 2014

post: show the default value of -w

--- a/post.c
+++ b/post.c
@@ -355,7 +355,7 @@
 			return;
 		}
 	}
 	/* custom paper size in mm, like 210x297 for a4 */
 	if (isdigit(s[0]) && strchr(s, 'x')) {
 		ps_pagewidth = atoi(s);
 		ps_pageheight = atoi(strchr(s, 'x') + 1);
@@ -387,8 +387,8 @@
 	"Usage: neatpost [options] <input >output\n"
 	"Options:\n"
 	"  -F dir  \tset font directory (" TROFFFDIR ")\n"
-	"  -p size \tset paper size (letter)\n"
-	"  -w lwid \tdrawing line thickness in thousandths of an em\n";
+	"  -p size \tset paper size; e.g., a4, letter, 2100x2970 (letter)\n"
+	"  -w lwid \tdrawing line thickness in thousandths of an em (40)\n";
 
 int main(int argc, char *argv[])
 {
@@ -355,7 +355,7 @@
 		}
 	}
-	/* custom paper size in mm, like 210x297 for a4 */
+	/* custom paper size in mm, like 2100x2970 for a4 */
 	if (isdigit(s[0]) && strchr(s, 'x')) {
 		ps_pagewidth = atoi(s);